@@ -1,5 +1,5 @@
 """
-Pycroscopy's I/O module
+Translators to extract data from custom & proprietary microscope formats and write them to HDF5 files.
 
 Submodules
 ----------
@@ -13,6 +13,7 @@ Submodules
 """
 from . import translators
 from .translators import *
+from .ingestor import ingest
 from .hdf_writer import HDFwriter
 from .virtual_data import VirtualDataset, VirtualGroup, VirtualData
 
