@@ -2,20 +2,23 @@
 """
 Created on Thursday July 27 2017
 
-@author: Rama Vasudevan, Chris R. Smith
+@author: Rama Vasudevan, Suhas Somnath, Chris R. Smith
 """
 
 from __future__ import division, print_function, absolute_import, unicode_literals
-
+import sys
 from os import path, remove, listdir  # File Path formatting
-
+import re
 import numpy as np  # For array operations
 import h5py
 from scipy.io import loadmat
-from pyUSID.io.translator import Translator, generate_dummy_main_parms
+from pyUSID.io.translator import Translator
 from pyUSID.io.write_utils import Dimension
-from pyUSID.io.hdf_utils import get_h5_obj_refs, link_h5_objects_as_attrs, \
-    write_simple_attrs, write_main_dataset, create_indexed_group
+from pyUSID.io.hdf_utils import write_simple_attrs, write_main_dataset, \
+    create_indexed_group
+
+if sys.version_info.major == 3:
+    unicode = str
 
 
 class TRKPFMTranslator(Translator):
@@ -27,6 +30,57 @@ class TRKPFMTranslator(Translator):
         super(TRKPFMTranslator, self).__init__(*args, **kwargs)
         self.raw_datasets = None
 
+    @staticmethod
+    def is_valid_file(data_path):
+        """
+        Checks whether the provided file can be read by this translator
+
+        Parameters
+        ----------
+        data_path : str
+            Path to folder or any data / parameter file within the folder
+
+        Returns
+        -------
+        obj : str
+            Path to file that will be accepted by the translate() function if
+            this translator is indeed capable of translating the provided file.
+            Otherwise, None will be returned
+        """
+
+        def get_chan_ind(line):
+            match_obj = re.match(r'(.*)_ch(..).dat', line, re.M | re.I)
+            type_list = [str, int]
+            if match_obj:
+                return \
+                    [type_caster(match_obj.group(ind)) for ind, type_caster in
+                     zip(range(1, 1 + len(type_list)), type_list)][-1]
+            else:
+                return None
+
+        if path.isfile(data_path):
+            # Assume that the file is amongst all other data files
+            folder_path, _ = path.split(data_path)
+        else:
+            folder_path = data_path
+
+        #  Now looking at the folder with  all necessary files:
+        file_list = listdir(path=folder_path)
+        parm_file_name = None
+        raw_data_paths = list()
+        for item in file_list:
+            if item.endswith('parm.mat'):
+                parm_file_name = item
+            elif isinstance(get_chan_ind(item), int):
+                raw_data_paths.append(item)
+
+        # Both the parameter and data files MUST be found:
+        if parm_file_name is not None and len(raw_data_paths) > 0:
+            # Returning the path to the parameter file since this is what the translate() expects:
+            return path.join(folder_path, parm_file_name)
+
+        return None
+
     def _parse_file_path(self, input_path):
         folder_path, base_name = path.split(input_path)
         base_name = base_name[:-8]
@@ -41,6 +95,7 @@ class TRKPFMTranslator(Translator):
         for file in listdir(folder_path):
             if '.dat' in file:
                 self.file_list.append(path.join(folder_path, file))
+        self.file_list = sorted(self.file_list)
 
     @staticmethod
     def _parse_spectrogram_size(file_handle):
@@ -112,8 +167,8 @@ class TRKPFMTranslator(Translator):
         num_pixels = parm_dict['grid_num_rows'] * parm_dict['grid_num_cols']
         print('Number of pixels: ', num_pixels)
         print('Count Values: ', count_vals)
-        if (num_pixels + 1) != count_vals:
-            print("Data size does not match number of pixels expected. Cannot continue")
+        #if (num_pixels + 1) != count_vals:
+        #    print("Data size does not match number of pixels expected. Cannot continue")
 
         #Find how many channels we have to make
         num_ai_chans = num_dat_files // 2  # Division by 2 due to real/imaginary
@@ -126,7 +181,7 @@ class TRKPFMTranslator(Translator):
         h5_meas_group = create_indexed_group(h5_file, 'Measurement')
 
         #Set up some parameters that will be written as attributes to this Measurement group
-        global_parms = generate_dummy_main_parms()
+        global_parms = dict()
         global_parms['data_type'] = 'trKPFM'
         global_parms['translator'] = 'trKPFM'
         write_simple_attrs(h5_meas_group, global_parms)
@@ -138,14 +193,22 @@ class TRKPFMTranslator(Translator):
         #The excit_wfm only has the DC values without any information on cycles, time, etc.
         #What we really need is to add the time component. For every DC step there are some time steps.
 
-        num_time_steps = (spectrogram_size-5) //excit_wfm.size
+        num_time_steps = (spectrogram_size-5) //excit_wfm.size //2 #Need to divide by 2 because it considers on and off field
 
-        #Let's repeat the excitation so that we get the full vector of same size as the spectrogram
-        #TODO: Check if this is the norm for this type of dataset
+        #There should be three spectroscopic axes
+        #In order of fastest to slowest varying, we have
+        #time, voltage, field
 
-        full_spect_val = np.copy(excit_wfm).repeat(num_time_steps)
+        time_vec = np.linspace(0, parm_dict['IO_time'], num_time_steps)
+        print('Num time steps: {}'.format(num_time_steps))
+        print('DC Vec size: {}'.format(excit_wfm.shape))
+        print('Spectrogram size: {}'.format(spectrogram_size))
+
+        field_vec = np.array([0,1])
+
+        spec_dims = [Dimension ('Time', 's', time_vec),Dimension('Field', 'Binary', field_vec),
+                     Dimension('Bias', 'V', excit_wfm)]
 
-        spec_dims = Dimension('Bias', 'V', full_spect_val)
         pos_dims = [Dimension('Cols', 'nm', parm_dict['grid_num_cols']),
                     Dimension('Rows', 'um', parm_dict['grid_num_rows'])]
 
